==> python-dateparser-0.7.6-1-any.pkg.tar.xz: usr/lib/python3.8/site-packages/dateparser/data/date_translation_data/cy.py <==
# -*- coding: utf-8 -*-
info = {
    "name": "cy",
    "date_order": "DMY",
    "january": [
        "ionawr",
        "ion"
    ],
    "february": [
        "chwefror",
        "chw",
        "chwef"
    ],
    "march": [
        "mawrth",
        "maw"
    ],
    "april": [
        "ebrill",
        "ebr"
    ],
    "may": [
        "mai"
    ],
    "june": [
        "mehefin",
        "meh"
    ],
    "july": [
        "gorffennaf",
        "gor",
        "gorff"
    ],
    "august": [
        "awst"
    ],
    "september": [
        "medi"
    ],
    "october": [
        "hydref",
        "hyd"
    ],
    "november": [
        "tachwedd",
        "tach"
    ],
    "december": [
        "rhagfyr",
        "rhag"
    ],
    "monday": [
        "dydd llun",
        "llun"
    ],
    "tuesday": [
        "dydd mawrth",
        "maw"
    ],
    "wednesday": [
        "dydd mercher",
        "mer"
    ],
    "thursday": [
        "dydd iau",
        "iau"
    ],
    "friday": [
        "dydd gwener",
        "gwe",
        "gwen"
    ],
    "saturday": [
        "dydd sadwrn",
        "sad"
    ],
    "sunday": [
        "dydd sul",
        "sul"
    ],
    "am": [
        "yb"
    ],
    "pm": [
        "yh"
    ],
    "year": [
        "blwyddyn",
        "bl"
    ],
    "month": [
        "mis"
    ],
    "week": [
        "wythnos"
    ],
    "day": [
        "dydd"
    ],
    "hour": [
        "awr"
    ],
    "minute": [
        "munud",
        "mun"
    ],
    "second": [
        "eiliad"
    ],
    "relative-type": {
        "1 year ago": [
            "llynedd"
        ],
        "0 year ago": [
            "eleni"
        ],
        "in 1 year": [
            "blwyddyn nesaf"
        ],
        "1 month ago": [
            "mis diwethaf"
        ],
        "0 month ago": [
            "y mis hwn"
        ],
        "in 1 month": [
            "mis nesaf"
        ],
        "1 week ago": [
            "wythnos ddiwethaf"
        ],
        "0 week ago": [
            "yr wythnos hon"
        ],
        "in 1 week": [
            "wythnos nesaf"
        ],
        "1 day ago": [
            "ddoe"
        ],
        "0 day ago": [
            "heddiw"
        ],
        "in 1 day": [
            "yfory"
        ],
        "0 hour ago": [
            "yr awr hon"
        ],
        "0 minute ago": [
            "y funud hon"
        ],
        "0 second ago": [
            "nawr"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "ymhen (\\d+) mlynedd"
        ],
        "\\1 year ago": [
            "(\\d+) o flynyddoedd yn ôl"
        ],
        "in \\1 month": [
            "ymhen (\\d+) mis"
        ],
        "\\1 month ago": [
            "(\\d+) mis yn ôl"
        ],
        "in \\1 week": [
            "ymhen (\\d+) wythnos"
        ],
        "\\1 week ago": [
            "(\\d+) wythnos yn ôl"
        ],
        "in \\1 day": [
            "ymhen (\\d+) diwrnod"
        ],
        "\\1 day ago": [
            "(\\d+) diwrnod yn ôl"
        ],
        "in \\1 hour": [
            "ymhen (\\d+) awr"
        ],
        "\\1 hour ago": [
            "(\\d+) awr yn ôl"
        ],
        "in \\1 minute": [
            "ymhen (\\d+) munud",
            "ymhen (\\d+) mun"
        ],
        "\\1 minute ago": [
            "(\\d+) munud yn ôl",
            "(\\d+) mun yn ôl"
        ],
        "in \\1 second": [
            "ymhen (\\d+) eiliad"
        ],
        "\\1 second ago": [
            "(\\d+) eiliad yn ôl"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}

==> python-dateparser-1.1.0-1-any.pkg.tar.xz: usr/lib/python3.9/site-packages/dateparser/data/date_translation_data/cy.py <==
info = {
    "name": "cy",
    "date_order": "DMY",
    "january": [
        "ion",
        "ionawr"
    ],
    "february": [
        "chw",
        "chwef",
        "chwefror"
    ],
    "march": [
        "maw",
        "mawrth"
    ],
    "april": [
        "ebr",
        "ebrill"
    ],
    "may": [
        "mai"
    ],
    "june": [
        "meh",
        "mehefin"
    ],
    "july": [
        "gor",
        "gorff",
        "gorffennaf"
    ],
    "august": [
        "awst"
    ],
    "september": [
        "medi"
    ],
    "october": [
        "hyd",
        "hydref"
    ],
    "november": [
        "tach",
        "tachwedd"
    ],
    "december": [
        "rhag",
        "rhagfyr"
    ],
    "monday": [
        "dydd llun",
        "llun"
    ],
    "tuesday": [
        "dydd mawrth",
        "maw"
    ],
    "wednesday": [
        "dydd mercher",
        "mer"
    ],
    "thursday": [
        "dydd iau",
        "iau"
    ],
    "friday": [
        "dydd gwener",
        "gwe",
        "gwen"
    ],
    "saturday": [
        "dydd sadwrn",
        "sad"
    ],
    "sunday": [
        "dydd sul",
        "sul"
    ],
    "am": [
        "yb"
    ],
    "pm": [
        "yh"
    ],
    "year": [
        "bl",
        "blwyddyn"
    ],
    "month": [
        "mis"
    ],
    "week": [
        "wythnos"
    ],
    "day": [
        "dydd"
    ],
    "hour": [
        "awr"
    ],
    "minute": [
        "mun",
        "munud"
    ],
    "second": [
        "eiliad"
    ],
    "relative-type": {
        "0 day ago": [
            "heddiw"
        ],
        "0 hour ago": [
            "yr awr hon"
        ],
        "0 minute ago": [
            "y funud hon"
        ],
        "0 month ago": [
            "y mis hwn"
        ],
        "0 second ago": [
            "nawr"
        ],
        "0 week ago": [
            "yr wythnos hon"
        ],
        "0 year ago": [
            "eleni"
        ],
        "1 day ago": [
            "ddoe"
        ],
        "1 month ago": [
            "mis diwethaf"
        ],
        "1 week ago": [
            "wythnos ddiwethaf"
        ],
        "1 year ago": [
            "llynedd"
        ],
        "in 1 day": [
            "yfory"
        ],
        "in 1 month": [
            "mis nesaf"
        ],
        "in 1 week": [
            "wythnos nesaf"
        ],
        "in 1 year": [
            "blwyddyn nesaf"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+) diwrnod yn ôl"
        ],
        "\\1 hour ago": [
            "(\\d+) awr yn ôl"
        ],
        "\\1 minute ago": [
            "(\\d+) mun yn ôl",
            "(\\d+) munud yn ôl"
        ],
        "\\1 month ago": [
            "(\\d+) mis yn ôl"
        ],
        "\\1 second ago": [
            "(\\d+) eiliad yn ôl"
        ],
        "\\1 week ago": [
            "(\\d+) wythnos yn ôl"
        ],
        "\\1 year ago": [
            "(\\d+) o flynyddoedd yn ôl"
        ],
        "in \\1 day": [
            "ymhen (\\d+) diwrnod"
        ],
        "in \\1 hour": [
            "ymhen (\\d+) awr"
        ],
        "in \\1 minute": [
            "ymhen (\\d+) mun",
            "ymhen (\\d+) munud"
        ],
        "in \\1 month": [
            "ymhen (\\d+) mis"
        ],
        "in \\1 second": [
            "ymhen (\\d+) eiliad"
        ],
        "in \\1 week": [
            "ymhen (\\d+) wythnos"
        ],
        "in \\1 year": [
            "ymhen (\\d+) mlynedd"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
